package
module
Version:
v0.0.0-...-0f97ec1
Opens a new window with list of versions in this module.
Published: Sep 10, 2020
License: GPL-3.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Engine struct {
Hash int
Threads int
ExperimentSettings bool
}
type Evaluator interface {
Evaluate(p *Position) int
}
type SortTable interface {
Clear()
Update(p *Position, bestMove Move, searched []Move, depth, height int)
Note(p *Position, ml []OrderedMove, trans Move, height int)
NoteQS(p *Position, ml []OrderedMove)
}
type TimeManager interface {
OnNodesChanged(nodes int)
OnIterationComplete(line mainLine)
Close()
}
type TransTable interface {
Megabytes() int
PrepareNewSearch()
Clear()
Read(p *Position) (depth, score, bound int, move Move, ok bool)
Update(p *Position, depth, score, bound int, move Move)
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.